/*****************************************************************************
**                                                                          **
**  Name:   LDF for Blackfin processors                                     **
**                                                                          **
******************************************************************************

 (C) Copyright 2007-2008 - Analog Devices, Inc.  All rights reserved.


 Notes:
 0xFF807FEF-0xFF807FFF
 Required by boot-loader. Used as heap or cache below which is ok.
 Cannot contain initialized data or code.

*****************************************************************************/

/* requires "configurations.h" */

/*********************
* Pre-Define Section *
*********************/

#if __VISUALDSPVERSION__ <= 0x05000400

#if defined (__ADSPBF512__) || defined (__ADSPBF514__) || defined (__ADSPBF516__) || defined (__ADSPBF518__)
    #define __ADSPBF518_FAMILY__
#endif

#if defined (__ADSPBF522__) || defined (__ADSPBF524__) || defined (__ADSPBF526__)
    #define __ADSPBF526_FAMILY__
#endif

#if defined (__ADSPBF523__) || defined (__ADSPBF525__) || defined (__ADSPBF527__)
    #define __ADSPBF527_FAMILY__
#endif

#if defined (__ADSPBF531__) || defined (__ADSPBF532__) || defined (__ADSPBF533__)
    #define __ADSPBF533_FAMILY__
#endif

#if defined (__ADSPBF534__) || defined (__ADSPBF536__) || defined (__ADSPBF537__)
    #define __ADSPBF537_FAMILY__
#endif

#if defined (__ADSPBF538__) || defined (__ADSPBF539__)
    #define __ADSPBF538_FAMILY__
#endif

#endif



/********
* Intro *
********/

#define L1_BANK_LENGTH              0x4000  /* 16kB */
#define L1_SUPER_BANK_LENGTH        0x8000  /* 32kB */
#define L1_SUB_BANK_LENGTH          0x1000  /* 4kB */



/* The definition CPLB_DATA_SECTION_EN is used to reserve a 1kB area of internal L1 memory (either bank A or bank b) in the linker description file.
This area is used to store cplb related data */
#if defined (INSTR_CACHE_EN) || defined (DATA_CACHE_EN)
    #define CPLB_DATA_EN

    #if defined (__ADSPBF51x__) || defined (__ADSPBF52x__) || defined (__ADSPBF533__) || defined (__ADSPBF534__) || defined (__ADSPBF538_FAMILY__) || defined (__ADSPBF54x__) || defined (__ADSPBF561__)
        #define CPLB_DATA_SECTION_EN
    #endif
    #if defined (__ADSPBF531__) && defined (INSTR_CACHE_EN) && !defined (DATA_CACHE_EN)
        #define CPLB_DATA_SECTION_EN
    #endif
    #if defined (__ADSPBF532__) && ( defined (INSTR_CACHE_EN) || ( defined (DATA_CACHE_EN) && !defined (DATA_CACHE_AB) ) )
        #define CPLB_DATA_SECTION_EN
    #endif
    #if defined (__ADSPBF536__) && ( defined (INSTR_CACHE_EN) || ( defined (DATA_CACHE_EN) && !defined (DATA_CACHE_AB) ) )
        #define CPLB_DATA_SECTION_EN
    #endif
#endif



/***********
* Core MMR *
***********/

#define CORE_MMR_LENGTH             0x00200000  /* System MMR Register 2MB */
#define CORE_MMR_END                0xFFFFFFFF
#define CORE_MMR_START              0xFFE00000
#define CORE_MMR_BASE               0xFFE00000



/*************
* System MMR *
*************/

#define SYS_MMR_LENGTH              0x00200000  /* Core MMR Register 2MB */ 
#define SYS_MMR_END                 0xFFDFFFFF
#define SYS_MMR_START               0xFFC00000
#define SYS_MMR_BASE                0xFFC00000



/**************************
* Internal Scratchpad Mem *
**************************/

#define SCRATCH_LENGTH              0x00001000  /* Scratchpad SRAM 4kB */
#define SCRATCH_END                 0xFFB00FFF
#define SCRATCH_MID                 0xFFB00400
#define SCRATCH_START               0xFFB00000



/*************************************
* Internal L1 Instruction Cache/SRAM *
*************************************/

#if defined INSTR_CACHE_EN
    #define INSTR_CACHE_LENGTH          L1_BANK_LENGTH /* 16kB */
    #define INSTR_CACHE_END             0xFFA13FFF
    #define INSTR_CACHE_START           0xFFA10000
#else
    #define INSTR_SRAM_C_LENGTH         L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_C_END            0xFFA13FFF
    #define INSTR_SRAM_C_START          0xFFA10000
#endif



/*******************************
* Internal L1 Instruction SRAM *
*******************************/

#if defined (__ADSPBF531__) || defined (__ADSPBF532__)
    #define INSTR_SRAM_START        0xFFA08000
    #define INSTR_SRAM_A_START      INSTR_SRAM_START
#else
    #define INSTR_SRAM_START        0xFFA00000
    #define INSTR_SRAM_A_START      INSTR_SRAM_START
#endif



#if defined (__ADSPBF51x__) && ( __SILICON_REVISION__ != 0x000 )
    #define INSTR_SRAM_B_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_B_END        0xFFA07FFF
    #define INSTR_SRAM_B_START      0xFFA04000

    #define INSTR_SRAM_A_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_A_END        0xFFA03FFF

    #define INSTR_SRAM_LENGTH       L1_SUPER_BANK_LENGTH /* 32kB */
    #define INSTR_SRAM_END          0xFFA07FFF
#endif

#if defined (__ADSPBF51x__) && ( __SILICON_REVISION__ == 0x000 )
    #define INSTR_SRAM_B_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_B_END        0xFFA0BFFF
    #define INSTR_SRAM_B_START      0xFFA08000

    #define INSTR_SRAM_A_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_A_END        0xFFA03FFF

    #define INSTR_SRAM_LENGTH       L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_END          0xFFA07FFF
#endif



#if defined __ADSPBF531__
    #define INSTR_SRAM_A_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_A_END        0xFFA0BFFF

    #define INSTR_SRAM_LENGTH       L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_END          INSTR_SRAM_B_END
#endif



#if defined __ADSPBF532__
    #define INSTR_SRAM_B_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_B_END        0xFFA0BFFF
    #define INSTR_SRAM_B_START      0xFFA08000

    #define INSTR_SRAM_A_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_A_END        0xFFA07FFF

    #if defined INSTR_CACHE_EN
        #define INSTR_SRAM_LENGTH   L1_SUPER_BANK_LENGTH /* 32kB */
        #define INSTR_SRAM_END      0xFFA13FFF
    #else
        #define INSTR_SRAM_LENGTH   0xC000 /* 48kB */
        #define INSTR_SRAM_END      0xFFA13FFF
    #endif
#endif



#if defined (__ADSPBF533__) || defined (__ADSPBF538_FAMILY__)
    #define INSTR_SRAM_B_LENGTH     L1_SUPER_BANK_LENGTH  /* 32kB */
    #define INSTR_SRAM_B_END        0xFFA0BFFF
    #define INSTR_SRAM_B_START      0xFFA08000

    #define INSTR_SRAM_A_LENGTH     L1_SUPER_BANK_LENGTH  /* 32kB */
    #define INSTR_SRAM_A_END        0xFFA07FFF
    #define INSTR_SRAM_A_START      INSTR_SRAM_START    

    #if defined INSTR_CACHE_EN
        #define INSTR_SRAM_LENGTH   0x10000 /* 64kB */
        #define INSTR_SRAM_END      0xFFA0FFFF
    #else
        #define INSTR_SRAM_LENGTH   0x14000 /* 80kB */
        #define INSTR_SRAM_END      0xFFA13FFF
    #endif
#endif



#if defined (__ADSPBF52x__) || defined (__ADSPBF537_FAMILY__) || defined (__ADSPBF54x__)
    #define INSTR_SRAM_B_LENGTH     L1_BANK_LENGTH  /* 16kB */
    #define INSTR_SRAM_B_END        0xFFA0BFFF
    #define INSTR_SRAM_B_START      0xFFA08000

    #define INSTR_SRAM_A_UPPER_LENGTH   L1_BANK_LENGTH  /* 16kB */
    #define INSTR_SRAM_A_UPPER_END      0xFFA07FFF
    #define INSTR_SRAM_A_UPPER_START    0xFFA04000

    #define INSTR_SRAM_A_LOWER_LENGTH   L1_BANK_LENGTH  /* 16kB */
    #define INSTR_SRAM_A_LOWER_END      0xFFA03FFF
    #define INSTR_SRAM_A_LOWER_START    INSTR_SRAM_START

    #define INSTR_SRAM_A_LENGTH     L1_SUPER_BANK_LENGTH  /* 32kB */
    #define INSTR_SRAM_A_END        0xFFA07FFF
    #define INSTR_SRAM_A_START      INSTR_SRAM_START

    #define INSTR_SRAM_LENGTH       0xC000 /* 48kB */
    #define INSTR_SRAM_END          0xFFA0BFFF
#endif



#if defined __ADSPBF561__
    #define INSTR_SRAM_A_LENGTH     L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_A_END        0xFFA03FFF
    #define INSTR_SRAM_A_START      INSTR_SRAM_START

    #define INSTR_SRAM_LENGTH       L1_BANK_LENGTH /* 16kB */
    #define INSTR_SRAM_END          0xFFA03FFF
#endif



/***************************
* Internal Instruction ROM *
***************************/

#if defined __ADSPBF54x__
    #define INSTR_ROM_LENGTH        0x10000  /* Instr. ROM 64kB */
    #define INSTR_ROM_END           0xFFA23FFF
    #define INSTR_ROM_START         0xFFA14000
#endif



/********************************
* Internal L1 Data SRAM & Cache *
********************************/

#if defined DATA_CACHE_EN
    #define DATA_CACHE_LENGTH           L1_BANK_LENGTH  /* 16kB */

    #define DATA_CACHE_A_LENGTH         DATA_CACHE_LENGTH
    #define DATA_CACHE_A_END            0xFF807FFF
    #define DATA_CACHE_A_START          0xFF804000

    #if !defined __ADSPBF531__
        #define DATA_CACHE_B_LENGTH     DATA_CACHE_LENGTH
        #define DATA_CACHE_B_END        0xFF907FFF
        #define DATA_CACHE_B_START      0xFF904000
    #endif
#endif



#if defined __ADSPBF531__
    /* L1 Data Bank B */
    #if defined (DATA_CACHE_EN) && defined (DATA_CACHE_AB)
        /* no Data Bank B SRAM */
    #else
        /* no Data Bank B SRAM */
    #endif

    /* L1 Data Bank A */
    #if defined DATA_CACHE_EN
        /* Data Bank A SRAM 0kB */
    #elif defined (INSTR_CACHE_EN) && defined (CPLB_DATA_SECTION_EN)
        #define DATA_SRAM_A_LENGTH  0x3C00 /* 15kB */
        #define DATA_SRAM_A_END     0xFF807FFF
        #define DATA_SRAM_A_START   0xFF804400
        #define CBLB_DATA_LENGTH    0x400 /* 1kB */
        #define CPLB_DATA_END       0xFF8043FF
        #define CPLB_DATA_START     0xFF804000
    #else
        #define DATA_SRAM_A_LENGTH  L1_BANK_LENGTH /* 16kB */
        #define DATA_SRAM_A_END     0xFF807FFF
        #define DATA_SRAM_A_START   0xFF804000
    #endif
#endif



#if defined (__ADSPBF532__) || defined (__ADSPBF536__)
    /* L1 Data Bank B */
    #if defined (DATA_CACHE_EN) && defined (DATA_CACHE_AB)
        /* Data Bank B SRAM 0kB */
    #elif defined (CPLB_DATA_SECTION_EN)
        #define DATA_SRAM_B_LENGTH  0x3C00 /* 15kB */
        #define DATA_SRAM_B_END     0xFF907FFF
        #define DATA_SRAM_B_START   0xFF904400
        #define CBLB_DATA_LENGTH    0x400 /* 1kB */
        #define CPLB_DATA_END       0xFF9043FF
        #define CPLB_DATA_START     0xFF904000
    #else /* !CPLB_DATA_SECTION_EN */
        #define DATA_SRAM_B_LENGTH  L1_BANK_LENGTH /* 16kB */
        #define DATA_SRAM_B_END     0xFF907FFF
        #define DATA_SRAM_B_START   0xFF904000
    #endif

    /* L1 Data Bank A */
    #if defined DATA_CACHE_EN
        /* Data Bank A SRAM 0kB */
    #else
        #define DATA_SRAM_A_LENGTH  L1_BANK_LENGTH /* 16kB */
        #define DATA_SRAM_A_END     0xFF807FFF
        #define DATA_SRAM_A_START   0xFF804000
    #endif
#endif



#if defined (__ADSPBF51x__) || defined (__ADSPBF52x__) || defined (__ADSPBF533__) || defined (__ADSPBF534__) || defined (__ADSPBF537__) || defined (__ADSPBF538_FAMILY__) || defined (__ADSPBF54x__) || defined (__ADSPBF561__)
    /* L1 Data Bank B */
    #if defined (DATA_CACHE_EN) && defined (DATA_CACHE_AB)
        #define DATA_SRAM_B_LENGTH  L1_BANK_LENGTH /* 16kB */
        #define DATA_SRAM_B_END     0xFF903FFF
        #define DATA_SRAM_B_START   0xFF900000
    #else /* no data bank b caching */
        #define DATA_SRAM_B_LENGTH  L1_SUPER_BANK_LENGTH /* 32kB */
        #define DATA_SRAM_B_END     0xFF907FFF
        #define DATA_SRAM_B_START   0xFF900000
    #endif

    /* L1 Data Bank A */
    #if defined CPLB_DATA_SECTION_EN
        #if defined DATA_CACHE_EN
            #define DATA_SRAM_A_LENGTH  0x3C00 /* 15kB */
            #define DATA_SRAM_A_END     0xFF803FFF
            #define DATA_SRAM_A_START   0xFF800400
        #elif defined INSTR_CACHE_EN /* instr. cache only */
            #define DATA_SRAM_A_LENGTH  0x7C00 /* 31kB */
            #define DATA_SRAM_A_END     0xFF807FFF
            #define DATA_SRAM_A_START   0xFF800400
        #endif
        #define CBLB_DATA_LENGTH    0x400 /* 1kB */
        #define CPLB_DATA_END       0xFF8003FF
        #define CPLB_DATA_START     0xFF800000
    #else /* no data/instr. cache */
        #define DATA_SRAM_A_LENGTH  L1_SUPER_BANK_LENGTH /* 32kB */
        #define DATA_SRAM_A_END     0xFF807FFF
        #define DATA_SRAM_A_START   0xFF800000
    #endif
#endif



/*******************
* Internal L2 SRAM *
*******************/

#if defined (__ADSPBF54x__) || defined (__ADSPBF561__)
    #if !defined __ADSPBF542__
        #define L2_SRAM_START       0xFEB00000
    #endif
    #if defined __ADSPBF544__
        #define L2_SRAM_END         0xFEB0FFFF
        #define L2_SRAM_LENGTH      0x10000  /* L2 SRAM 64kB */
    #endif
    #if defined (__ADSPBF547__) || defined (__ADSPBF548__) || defined (__ADSPBF549__) || defined (__ADSPBF561__)
        #define L2_SRAM_END         0xFEB1FFFF
        #define L2_SRAM_LENGTH      0x20000  /* L2 SRAM 128kB */
    #endif
#endif



/***********
* Boot ROM *
***********/

#if defined (__ADSPBF51x__) || defined (__ADSPBF52x__)
    #define BOOT_ROM_LENGTH             0x8000 /* 32KB */
    #define BOOT_ROM_END                0xEF007FFF
    #define BOOT_ROM_START              0xEF000000
#endif

#if defined __ADSPBF54x__
    #define BOOT_ROM_LENGTH             0x1000 /* 4kB */
    #define BOOT_ROM_END                0xEF000FFF
    #define BOOT_ROM_START              0xEF000000
#endif

#if defined (__ADSPBF537_FAMILY__) || defined (__ADSPBF561__)
    #define BOOT_ROM_LENGTH             0x800 /* 2KB */
    #define BOOT_ROM_END                0xEF0007FF
    #define BOOT_ROM_START              0xEF000000
#endif

#if defined (__ADSPBF533_FAMILY__) || defined (__ADSPBF538_FAMILY__)
    #define BOOT_ROM_LENGTH             0x400 /* 1KB */
    #define BOOT_ROM_END                0xEF0003FF
    #define BOOT_ROM_START              0xEF000000
#endif



/************
* Async Mem *
************/

#define ASYNC_MEM_START             0x20000000
#define ASYNC_MEM_BANK0_START       ASYNC_MEM_START

#if defined __ADSPBF54x__
    #define ASYNC_MEM_LENGTH        0x2000000 /* ADSP-BF548 EZ-KIT Lite: 32MB */
    #define ASYNC_MEM_BANK_LENGTH   0x2000000 /* ADSP-BF548 EZ-KIT Lite */
    #define ASYNC_MEM_END           0x21FFFFFF /* ADSP-BF548 EZ-KIT Lite */
#else
    #define ASYNC_MEM_LENGTH        0x400000 /* 4MB */
    #define ASYNC_MEM_END           0x202FFFFF
    #define ASYNC_MEM_BANK_LENGTH   0x100000 /* 1MB */
    #define ASYNC_MEM_BANK3_START   0x20300000
    #define ASYNC_MEM_BANK2_START   0x20200000
    #define ASYNC_MEM_BANK1_START   0x20100000 
#endif



/***********
* Sync Mem *
***********/

#if defined SDRAM_SIZE

    #define SDRAM_START             0x00000000
    #define SDRAM_BANK0_START       SDRAM_START

    #if SDRAM_SIZE == 512
        #define SDRAM_LENGTH        0x20000000
        #define SDRAM_END           0x1FFFFFFF
        #define SDRAM_BANK_LENGTH   0x08000000
        #define SDRAM_BANK3_START   0x18000000
        #define SDRAM_BANK2_START   0x10000000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 256
        #define SDRAM_LENGTH        0x10000000
        #define SDRAM_END           0x0FFFFFFF
        #define SDRAM_BANK_LENGTH   0x04000000
        #define SDRAM_BANK3_START   0x0C000000
        #define SDRAM_BANK2_START   0x08000000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 128
        #define SDRAM_LENGTH        0x08000000
        #define SDRAM_END           0x07FFFFFF
        #define SDRAM_BANK_LENGTH   0x02000000
        #define SDRAM_BANK3_START   0x06000000
        #define SDRAM_BANK2_START   0x04000000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 64
        #define SDRAM_LENGTH        0x04000000
        #define SDRAM_END           0x03FFFFFF
        #define SDRAM_BANK_LENGTH   0x01000000
        #define SDRAM_BANK3_START   0x03000000
        #define SDRAM_BANK2_START   0x02000000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 32
        #define SDRAM_LENGTH        0x02000000
        #define SDRAM_END           0x01FFFFFF
        #define SDRAM_BANK_LENGTH   0x00800000
        #define SDRAM_BANK3_START   0x01800000
        #define SDRAM_BANK2_START   0x01000000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 16
        #define SDRAM_LENGTH        0x01000000
        #define SDRAM_END           0x00FFFFFF
        #define SDRAM_BANK_LENGTH   0x00400000
        #define SDRAM_BANK3_START   0x00C00000
        #define SDRAM_BANK2_START   0x00800000
        #define SDRAM_BANK1_START   SDRAM_BANK_LENGTH
    #endif

    #if SDRAM_SIZE == 8
        #define SDRAM_LENGTH        0x01000000
        #define SDRAM_END           0x00FFFFFF
        #define SDRAM_BANK_LENGTH   0x00200000
        #define SDRAM_BANK3_START   0x00C00000
        #define SDRAM_BANK2_START   0x00800000
        #define SDRAM_BANK1_START   0x00400000
    #endif

#endif


/*****************************************************************************
 EOF
******************************************************************************/
