#include <blackfin.h>
#include <services_types.h>


/****************************************************************/
/*	Routine for Configuring the DCPLBs and Enabling Data Cache	*/
/*																*/
/*	Parameters:													*/
/*																*/
/*	cplb_addr : Pointer to the Page Table for DCPLB_ADDR		*/
/*	cplb_data : Pointer to the Page Table for DCPLB_DATA		*/
/*	cplb_cnt  : Number of CPLB entries to be configured			*/
/*	banks	  : Number of data banks to be enabled as DCACHE	*/
/*																*/
/*									Initial Version				*/
/*									Kunal Singh					*/
/*									DSP applications, ADI		*/
/*									Dated 3 April, 2005			*/
/*																*/
/****************************************************************/
void Config_D_Cache(u32 *cplb_addr[], u32 *cplb_data, int cplb_cnt, int banks)
{
        u32 temp;

        /************************/
        /* Disable the DCPLBs   */
        /* Disable the D_Cache  */
        /* Invalidate Cache     */
        /************************/
        *pDMEM_CONTROL = 0x1;
        asm("CSYNC;");

        /* Configure the CPLB_ADDR Entries */
        for(temp = 0; temp<cplb_cnt; temp++)
        {
            *(pDCPLB_ADDR0 + temp) = *(cplb_addr + temp);
            asm("CSYNC;");
        }

        /* Configure DCPLB_DATA entries */
        for(temp = 0; temp<cplb_cnt; temp++)
        {
            *(pDCPLB_DATA0 + temp) = *(cplb_data + temp);
            asm("CSYNC;");
        }

        /* Enable Cache, Enable CPLBs */
        if (banks == 1)
        {
            /* Only one bank-A enabled as Cache */
            *pDMEM_CONTROL = 0x100B;
            asm("ssync;");
        }
        else
        {
            if (banks == 2)
            {
                /* Both the banks enabled as Cache */
                *pDMEM_CONTROL = 0x100F;
                asm("ssync;");
            }
        }

} /* Config_D_Cache */
